diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/area/Text.php b/core/modules/views/lib/Drupal/views/Plugin/views/area/Text.php
index 4c926ad..cd45efe 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/area/Text.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/area/Text.php
@@ -54,7 +54,7 @@ function render($empty = FALSE) {
     $format = isset($this->options['format']) ? $this->options['format'] : filter_default_format();
     if (!$empty || !empty($this->options['empty'])) {
       return array(
-        '#markup' => $this->render_textarea($this->options['content'], $format),
+        '#markup' => $this->renderTextarea($this->options['content'], $format),
       );
     }
 
@@ -64,7 +64,7 @@ function render($empty = FALSE) {
   /**
    * Render a text area, using the proper format.
    */
-  function render_textarea($value, $format) {
+  public function renderTextarea($value, $format) {
     if ($value) {
       if ($this->options['tokenize']) {
         $value = $this->view->style_plugin->tokenize_value($value, 0);
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/area/TextCustom.php b/core/modules/views/lib/Drupal/views/Plugin/views/area/TextCustom.php
index 002537a..55c547b 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/area/TextCustom.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/area/TextCustom.php
@@ -48,7 +48,7 @@ public function submitOptionsForm(&$form, &$form_state) {
   function render($empty = FALSE) {
     if (!$empty || !empty($this->options['empty'])) {
       return array(
-        '#markup' => $this->render_textarea($this->options['content']),
+        '#markup' => $this->renderTextarea($this->options['content']),
       );
     }
 
@@ -58,7 +58,7 @@ function render($empty = FALSE) {
   /**
    * Render a text area with filter_xss_admin.
    */
-  function render_textarea($value) {
+  public function renderTextarea($value) {
     if ($value) {
       if ($this->options['tokenize']) {
         $value = $this->view->style_plugin->tokenize_value($value, 0);
diff --git a/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php b/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php
index bc8dfff..05eca8c 100644
--- a/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php
+++ b/core/modules/views/lib/Drupal/views/Plugin/views/field/FieldPluginBase.php
@@ -1152,7 +1152,7 @@ function advanced_render($values) {
       if (is_array($value)) {
         $value = drupal_render($value);
       }
       // This happens here so that render_as_link can get the unaltered value of
       // this field as a token rather than the altered value.
       $this->last_render = $value;
     }
@@ -1270,7 +1270,7 @@ function render_text($alter) {
       if (!isset($tokens)) {
         $tokens = $this->get_render_tokens($alter);
       }
-      $value = $this->render_as_link($alter, $value, $tokens);
+      $value = $this->renderAsLink($alter, $value, $tokens);
     }
 
     return $value . $suffix;
@@ -1303,7 +1303,7 @@ function render_trim_text($alter, $value) {
    * Render this field as a link, with the info from a fieldset set by
    * the user.
    */
-  function render_as_link($alter, $text, $tokens) {
+  public function renderAsLink($alter, $text, $tokens) {
     $value = '';
 
     if (!empty($alter['prefix'])) {
@@ -1152,7 +1152,7 @@ function advanced_render($values) {
         $value = drupal_render($value);
       }
-      // This happens here so that render_as_link can get the unaltered value of
+      // This happens here so that renderAsLink can get the unaltered value of
       // this field as a token rather than the altered value.
       $this->last_render = $value;
